@@ -151,11 +151,13 @@ class Node(BaseModel):
 
         url: str = None
 
-    def __eq__(self, other) -> bool:
-        return hash(self) == hash(other)
+    def __eq__(self, other: Node) -> bool:
+        if not isinstance(other, Node):
+            return False
+        return f"{hash(self)}{self.json()}" == f"{hash(other)}{other.json()}"
 
     def __hash__(self) -> int:
-        return hash(f"{self.__class__.__name__}{self.json()}")
+        return hash(f"{self.__class__.__name__}{self.id}")
 
     @property
     def cache(self) -> CacheManager:
