@@ -114,7 +114,7 @@ class Resolver(BaseModel, T.Generic[NodeType]):
             value_to_save = nested_d
             if nested_d:
                 val = (
-                    [resolver.parse_obj_nested(d) for d in nested_d]
+                    {resolver.parse_obj_nested(d) for d in nested_d}
                     if type(nested_d) == list
                     else resolver.parse_obj_nested(nested_d)
                 )
